@@ -1,4 +1,3 @@
-# coding: utf-8
 # Copyright (c) Materials Virtual Lab.
 # Distributed under the terms of the BSD License.
 
@@ -25,7 +24,6 @@ __date__ = "March 14, 2017"
 
 # TODO: (1) ipython notebook example files, unittests
 from pymatgen.symmetry.structure import SymmetrizedStructure
-
 from pymatgen.analysis.diffusion.utils.supercells import (
     get_sc_fromstruct,
     get_start_end_structures,
@@ -299,6 +297,7 @@ class MigrationHop(MSONable):
         isite: Site,
         esite: Site,
         symm_structure: SymmetrizedStructure,
+        host_symm_struct: SymmetrizedStructure = None,
         symprec: float = 0.001,
     ):
         """
@@ -306,6 +305,7 @@ class MigrationHop(MSONable):
             isite: Initial site
             esite: End site
             symm_structure: SymmetrizedStructure
+            host_symm_struct: SymmetrizedStructure of the host structure, used to for its spacegroup
             symprec: used to determine equivalence
         """
         self.isite = isite
@@ -315,7 +315,11 @@ class MigrationHop(MSONable):
         self.symm_structure = symm_structure
         self.symprec = symprec
         self.msite = PeriodicSite(esite.specie, (isite.frac_coords + esite.frac_coords) / 2, esite.lattice)
-        sg = self.symm_structure.spacegroup
+        if host_symm_struct:
+            self.host_symm_structure = host_symm_struct
+            sg = self.host_symm_structure.spacegroup
+        else:
+            sg = self.symm_structure.spacegroup
         for i, sites in enumerate(self.symm_structure.equivalent_sites):
             if sg.are_symmetrically_equivalent([isite], [sites[0]]):
                 self.iindex = i
@@ -348,24 +352,15 @@ class MigrationHop(MSONable):
             raise RuntimeError(f"No symmetrically equivalent site was found for {esite}")
 
     def __repr__(self):
+        ifc = self.isite.frac_coords
+        efc = self.esite.frac_coords
         return (
-            "Path of %.4f A from %s [%.3f, %.3f, %.3f] "
-            "(ind: %d, Wyckoff: %s) to %s [%.3f, %.3f, %.3f] (ind: %d, Wyckoff: %s)"
-            % (
-                self.length,
-                self.isite.specie,
-                self.isite.frac_coords[0],
-                self.isite.frac_coords[1],
-                self.isite.frac_coords[2],
-                self.iindex,
-                self.symm_structure.wyckoff_symbols[self.iindex],
-                self.esite.specie,
-                self.esite.frac_coords[0],
-                self.esite.frac_coords[1],
-                self.esite.frac_coords[2],
-                self.eindex,
-                self.symm_structure.wyckoff_symbols[self.eindex],
-            )
+            f"Path of {self.length:.4f} A from {self.isite.specie} "
+            f"[{ifc[0]:.3f}, {ifc[1]:.3f}, {ifc[2]:.3f}] "
+            f"(ind: {self.iindex}, Wyckoff: {self.symm_structure.wyckoff_symbols[self.iindex]}) "
+            f"to {self.esite.specie} "
+            f"[{efc[0]:.3f}, {efc[1]:.3f}, {efc[2]:.3f}] "
+            f"(ind: {self.eindex}, Wyckoff: {self.symm_structure.wyckoff_symbols[self.eindex]})"
         )
 
     @property
@@ -443,9 +438,12 @@ class MigrationHop(MSONable):
             if site.specie != self.isite.specie:
                 other_sites.append(site)
             else:
-                if not vac_mode or (self.isite.distance(site) <= 1e-8 or self.esite.distance(site) <= 1e-8):
+                if self.isite.distance(site) <= 1e-8 or self.esite.distance(site) <= 1e-8:
+                    migrating_specie_sites.append(site)
                     continue
-                migrating_specie_sites.append(site)
+
+                if vac_mode:
+                    other_sites.append(site)
         return migrating_specie_sites, other_sites
 
     def get_sc_structures(
@@ -472,7 +470,10 @@ class MigrationHop(MSONable):
 
         """
         migrating_specie_sites, other_sites = self._split_migrating_and_other_sites(vac_mode)
-        base_struct = Structure.from_sites(other_sites)
+        if vac_mode:
+            base_struct = Structure.from_sites(other_sites + migrating_specie_sites)
+        else:
+            base_struct = Structure.from_sites(other_sites)
         sc_mat = get_sc_fromstruct(
             base_struct=base_struct,
             min_atoms=min_atoms,
