@@ -1,4 +1,3 @@
-# coding: utf-8
 # Copyright (c) Materials Virtual Lab.
 # Distributed under the terms of the BSD License.
 import os
@@ -14,6 +13,7 @@ from pymatgen.analysis.diffusion.neb.full_path_mapper import (
     MigrationGraph,
     MigrationHop,
     get_hop_site_sequence,
+    order_path,
 )
 from pymatgen.analysis.diffusion.neb.periodic_dijkstra import _get_adjacency_with_images
 
@@ -163,27 +163,64 @@ class MigrationGraphComplexTest(unittest.TestCase):
 
     def test_get_path(self):
         self.fpm_li.assign_cost_to_graph()  # use 'hop_distance'
-        paths = [*self.fpm_li.get_path()]
+        paths = [*self.fpm_li.get_path(flip_hops=False)]
         p_strings = {"->".join(map(str, get_hop_site_sequence(ipath, start_u=u))) for u, ipath in paths}
         self.assertIn("5->7->5", p_strings)
         # convert each pathway to a string representation
-        paths = [*self.fpm_li.get_path(max_val=2.0)]
+        paths = [*self.fpm_li.get_path(max_val=2.0, flip_hops=False)]
         p_strings = {"->".join(map(str, get_hop_site_sequence(ipath, start_u=u))) for u, ipath in paths}
 
         # After checking trimming the graph more hops are needed for the same path
         self.assertIn("5->3->7->2->5", p_strings)
 
         self.fpm_mg.assign_cost_to_graph()  # use 'hop_distance'
-        paths = [*self.fpm_mg.get_path()]
+        paths = [*self.fpm_mg.get_path(flip_hops=False)]
         p_strings = {"->".join(map(str, get_hop_site_sequence(ipath, start_u=u))) for u, ipath in paths}
         self.assertIn("1->0->1", p_strings)
 
+    def test_get_key_in_path(self):
+        self.fpm_li.assign_cost_to_graph()  # use 'hop_distance'
+        paths = [*self.fpm_li.get_path(flip_hops=False)]
+        hop_seq_info = [get_hop_site_sequence(ipath, start_u=u, key="hop_distance") for u, ipath in paths]
+
+        hop_distances = {}
+        for u, ipath in paths:
+            hop_distances[u] = []
+            for hop in ipath:
+                hop_distances[u].append(hop["hop_distance"])
+
+        # Check that the right key and respective values were pulled
+        for u, distances in hop_distances.items():
+            self.assertEqual(distances, hop_seq_info[u][1])
+            print(distances, hop_seq_info[u][1])
+
     def test_not_matching_first(self):
         structure = Structure.from_file(f"{dir_path}/pathfinder_files/Li6MnO4.json")
         fpm_lmo = MigrationGraph.with_distance(structure, "Li", max_distance=4)
         for u, v, d in fpm_lmo.m_graph.graph.edges(data=True):
             self.assertIn(d["hop"].eindex, {0, 1})
 
+    def test_order_path(self):
+        # add list data to migration graph - to test if list data is flipped
+        for n, hop_d in self.fpm_li.unique_hops.items():
+            data = {"data": [hop_d["iindex"], hop_d["eindex"]]}
+            self.fpm_li.add_data_to_similar_edges(n, data, hop_d["hop"])
+
+        self.fpm_li.assign_cost_to_graph()  # use 'hop_distance'
+
+        for n, hop_list in [*self.fpm_li.get_path(flip_hops=False)]:
+            ordered = order_path(hop_list, n)
+
+            # check if isites and esites are oriented to form a coherent path
+            for h1, h2 in zip(ordered[:-1], ordered[1:]):
+                self.assertEqual(h1["eindex"], h2["iindex"])
+
+            # if hop was flipped, check list data was flipped too
+            for h, ord_h in zip(hop_list, ordered):
+                if h["iindex"] != ord_h["iindex"]:  # check only if hop was flipped
+                    self.assertEqual(h["data"][0], ord_h["data"][-1])
+                    self.assertEqual(h["data"][-1], ord_h["data"][0])
+
 
 class ChargeBarrierGraphTest(unittest.TestCase):
     def setUp(self):
@@ -239,7 +276,7 @@ class ChargeBarrierGraphTest(unittest.TestCase):
         """
         self.cbg.populate_edges_with_chg_density_info()
         length_vs_chg = list(
-            sorted([(d["hop"].length, d["chg_total"]) for u, v, d in self.cbg.m_graph.graph.edges(data=True)])
+            sorted((d["hop"].length, d["chg_total"]) for u, v, d in self.cbg.m_graph.graph.edges(data=True))
         )
         prv = None
         for length, chg in length_vs_chg:
